@@ -3,7 +3,7 @@
 /*
     This file is part of Magnum.
 
-    Copyright © 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018
+    Copyright © 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019
               Vladimír Vondruš <mosra@centrum.cz>
 
     Permission is hereby granted, free of charge, to any person obtaining a
@@ -55,7 +55,11 @@ namespace Magnum { namespace Trade {
 /**
 @brief Image importer plugin using stb_image
 
-Supports the following formats:
+@m_keywords{BmpImporter GifImporter HdrImporter JpegImporter PgmImporter}
+@m_keywords{PicImporter PngImporter PpmImporter PsdImporter TgaImporter}
+
+Supports the following formats using the
+[stb_image](https://github.com/nothings/stb) library:
 
 -   Windows Bitmap (`*.bmp`), only non-1bpp, no RLE
 -   Graphics Interchange Format (`*.gif`)
@@ -77,7 +81,8 @@ dynamic plugin, you need to load the @cpp "StbImageImporter" @ce plugin from
 `MAGNUM_PLUGINS_IMPORTER_DIR`. To use as a static plugin or as a dependency of
 another plugin with CMake, you need to request the `StbImageImporter` component
 of the `MagnumPlugins` package and link to the
-`MagnumPlugins::StbImageImporter` target.
+`MagnumPlugins::StbImageImporter` target. See @ref building-plugins,
+@ref cmake-plugins and @ref plugins for more information.
 
 This plugins provides `BmpImporter`, `GifImporter`, `HdrImporter`,
 `JpegImporter`, `PgmImporter`, `PicImporter`, `PngImporter`, `PpmImporter`,
@@ -85,8 +90,18 @@ This plugins provides `BmpImporter`, `GifImporter`, `HdrImporter`,
 complete support for all format quirks and the performance might be worse than
 when using plugin dedicated for given format.
 
-See @ref building-plugins, @ref cmake-plugins and @ref plugins for more
-information.
+@m_class{m-block m-primary}
+
+@thirdparty This plugin makes use of the
+    [stb_image](https://github.com/nothings/stb) library by Sean Barrett,
+    released into the @m_class{m-label m-primary} **public domain**
+    ([license text](https://github.com/nothings/stb/blob/e6afb9cbae4064da8c3e69af3ff5c4629579c1d2/stb_image.h#L7444-L7460),
+    [choosealicense.com](https://choosealicense.com/licenses/unlicense/)),
+    or alternatively under @m_class{m-label m-success} **MIT**
+    ([license text](https://github.com/nothings/stb/blob/e6afb9cbae4064da8c3e69af3ff5c4629579c1d2/stb_image.h#L7426-L7442),
+    [choosealicense.com](https://choosealicense.com/licenses/mit/)).
+
+@section Trade-StbImageImporter-limitations Behavior and limitations
 
 The images are imported with @ref PixelFormat::RGB8Unorm,
 @ref PixelFormat::RGBA8Unorm, @ref PixelFormat::R8Unorm for grayscale or
@@ -96,6 +111,12 @@ images are imported with @ref PixelFormat::RGB32F, @ref PixelFormat::RGBA32F,
 default @ref PixelStorage parameters except for alignment, which may be changed
 to @cpp 1 @ce if the data require it.
 
+@subsection Trade-StbImageImporter-limitations-cgbi Apple CgBI PNGs
+
+CgBI is a proprietary Apple-specific extension to PNG
+([details here](http://iphonedevwiki.net/index.php/CgBI_file_format)). The
+importer detects those files and converts BGRA channels back to RGBA.
+
 @todo Enable ARM NEON when I'm able to test that
 */
 class MAGNUM_STBIMAGEIMPORTER_EXPORT StbImageImporter: public AbstractImporter {
